@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+"""
+Various test helper functions.
+"""
+
 import logging
 from os import path
 import time
@@ -13,12 +18,16 @@ def skip_test(reason='No reason given to skip_test'):
 def mark_slow(f):
     return f
 
-import _mssql
+mssql_server_required = pytest.mark.mssql_server_required
+
+from pymssql import _mssql
 import pymssql
 
 
 class Config(object):
-    pass
+    def __str__(self):
+        return f"server={self.server}, port={self.port}, database={self.database}, " \
+               f"user={self.user}, password={self.password}"
 
 config = Config()
 
@@ -27,7 +36,6 @@ tmpdir = path.join(cdir, 'tmp')
 cfgpath = path.join(cdir, 'tests.cfg')
 global_mssqlconn = None
 
-
 def mssqlconn(conn_properties=None):
     return _mssql.connect(
         server=config.server,
@@ -54,7 +62,11 @@ def get_app_lock():
     global global_mssqlconn
 
     if global_mssqlconn is None:
-        global_mssqlconn = mssqlconn()
+        try:
+            global_mssqlconn = mssqlconn()
+        except Exception as exc:
+            print(f"Could not connect to {config}:\n{exc}")
+            return False
 
     t1 = time.time()
 
@@ -78,9 +90,12 @@ def get_app_lock():
         "*** %d: sp_getapplock for 'pymssql_tests' returned %d - "
         "it took %d seconds"
         % (t2, result, t2 - t1))
+    return True
 
 
 def release_app_lock():
+    if global_mssqlconn is None:
+        return
     t1 = time.time()
     result = global_mssqlconn.execute_scalar("""
     DECLARE @result INTEGER;
@@ -285,6 +300,24 @@ class CursorBase(DBAPIBase):
         cur.fetchall()
         eq_(cur.rowcount, 5)
 
+    def test_fetchone_rowcount(self):
+        cur = self.execute('select * from test')
+        eq_(cur.rowcount, -1)
+
+        for _ in iter(cur.fetchone, None):
+            eq_(cur.rowcount, -1)
+
+        eq_(cur.rowcount, 5)
+
+    def test_fetchmany_rowcount(self):
+        cur = self.execute('select * from test')
+        eq_(cur.rowcount, -1)
+
+        for _ in iter(cur.fetchmany, []):
+            eq_(cur.rowcount, -1)
+
+        eq_(cur.rowcount, 5)
+
     def test_as_dict(self):
         # test for http://code.google.com/p/pymssql/issues/detail?id=92
         cur = self.conn.cursor(as_dict=True)
@@ -451,3 +484,24 @@ class StoredProc(object):
 
     def __exit__(self, type, value, tb):
         self.drop()
+
+
+def get_sql_server_version(mssql_connection):
+    """
+    Returns the version of the SQL Server in use:
+    """
+    result = mssql_connection.execute_scalar(
+        "SELECT CAST(SERVERPROPERTY('ProductVersion') as varchar)"
+    )
+    ver_code = int(result.split('.')[0])
+    if ver_code >= 12:
+        major_version = 2014
+    elif ver_code == 11:
+        major_version = 2012
+    elif ver_code == 10:
+        major_version = 2008
+    elif ver_code == 9:
+        major_version = 2005
+    else:
+        major_version = 2000
+    return major_version
