@@ -1,15 +1,15 @@
+# -*- coding: utf-8 -*-
 """
 Test context managers -- i.e.: the `with` statement
 """
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from pymssql import InterfaceError
-from .helpers import pymssqlconn
+from .helpers import pymssqlconn, mssqlconn, mssql_server_required
 
+
+@mssql_server_required
 class TestContextManagers(unittest.TestCase):
     def test_pymssql_Connection_with(self):
         with pymssqlconn() as conn:
@@ -34,3 +34,10 @@ class TestContextManagers(unittest.TestCase):
             cursor.execute("SELECT @@version AS version")
 
         self.assertEqual(str(context.exception), "Cursor is closed.")
+
+    def test_mssql_Connection_with(self):
+        with mssqlconn() as conn:
+            conn.execute_query("SELECT @@version AS version")
+            self.assertTrue(conn.connected)
+
+        self.assertFalse(conn.connected)
