@@ -1,14 +1,14 @@
+# -*- coding: utf-8 -*-
+"""
+Test queries with debug on.
+"""
+
 from contextlib import contextmanager
-try:
-    # Python 2
-    from StringIO import StringIO
-except ImportError:
-    # Python 3
-    from io import StringIO
+from io import StringIO
 import sys
 import unittest
 
-from .helpers import mssqlconn
+from .helpers import mssqlconn, mssql_server_required
 
 
 @contextmanager
@@ -18,6 +18,7 @@ def redirect_stderr():
     sys.stderr = sys.__stderr__
 
 
+@mssql_server_required
 class TestMSSQLConnectionWithDebugQueries(unittest.TestCase):
 
     def setUp(self):
