@@ -1,10 +1,16 @@
+# -*- coding: utf-8 -*-
+"""
+Test queries.
+"""
+
 from datetime import datetime
 import unittest
 
-import _mssql
+from pymssql import _mssql
 
-from .helpers import mssqlconn, drop_table
+from .helpers import mssqlconn, drop_table, mssql_server_required
 
+@mssql_server_required
 class QueryTests(unittest.TestCase):
 
     @classmethod
