@@ -1,12 +1,20 @@
+# -*- coding: utf-8 -*-
+"""
+Test stored procedure usage.
+"""
+
 import decimal
 import datetime
+import os
 import sys
 import unittest
 
 import pymssql
-import _mssql
+from pymssql import _mssql
 
-from .helpers import mssqlconn, pymssqlconn, eq_, skip_test
+import pytest
+
+from .helpers import mssqlconn, pymssqlconn, eq_, skip_test, get_sql_server_version, mssql_server_required
 
 FIXED_TYPES = (
     'BigInt',
@@ -19,14 +27,18 @@ FIXED_TYPES = (
     'SmallInt',
     'TinyInt',
     'UniqueIdentifier',
+    'Real',
+    'Float'
 )
 
 VARIABLE_TYPES = (
     ('Char', 4),
     ('VarChar', 4),
+    ('VarBinary', 4),
     ('Text', None)  # Leave this one in the last position in case it fails (see https://code.google.com/p/pymssql/issues/detail?id=113#c2)
 )
 
+@mssql_server_required
 class TestFixedTypeConversion(unittest.TestCase):
 
     def setUp(self):
@@ -199,6 +211,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         eq_(input, proc.parameters['@otinyint'])
 
     def testUuid(self):
+        if os.environ.get('FREETDS_VERSION') != '0.91':
+            pytest.xfail("UNIQUEIDENTIFIER as a SP param doesn't work with FreeTDS >= 0.95")
         import uuid
         input = uuid.uuid4()
         proc = self.mssql.init_procedure('pymssqlTestUniqueIdentifier')
@@ -207,7 +221,24 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.execute()
         eq_(input, proc.parameters['@ouniqueidentifier'])
 
+    def testReal(self):
+        input = 3.14
+        proc = self.mssql.init_procedure('pymssqlTestReal')
+        proc.bind(input, _mssql.SQLREAL, '@ireal')
+        proc.bind(None, _mssql.SQLREAL, '@oreal', output=True)
+        proc.execute()
+        assert abs(input - proc.parameters['@oreal']) < 0.00001
 
+    def testFloat8(self):
+        input = 3.40E38 + 1
+        proc = self.mssql.init_procedure('pymssqlTestFloat')
+        proc.bind(input, _mssql.SQLFLT8, '@ifloat')
+        proc.bind(None, _mssql.SQLFLT8, '@ofloat', output=True)
+        proc.execute()
+        assert abs(input - proc.parameters['@ofloat']) < 0.00001
+
+
+@mssql_server_required
 class TestCallProcFancy(unittest.TestCase):
     # "Fancy" because we test some exotic cases like passing None or Unicode
     # strings to a called procedure
@@ -347,6 +378,8 @@ class TestCallProcFancy(unittest.TestCase):
         eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u041c\u0438\u0440')
 
 
+
+@mssql_server_required
 class TestStringTypeConversion(unittest.TestCase):
 
     def setUp(self):
@@ -404,7 +437,84 @@ class TestStringTypeConversion(unittest.TestCase):
         proc.execute()
         eq_(input, proc.parameters['@ovarchar'])
 
+    def testVarBinary(self):
+        def check_conversion(input, output_type):
+            proc = self.mssql.init_procedure('pymssqlTestVarBinary')
+            proc.bind(input, _mssql.SQLVARBINARY, '@ivarbinary')
+            proc.bind(None, _mssql.SQLVARBINARY, '@ovarbinary', output=True)
+            proc.execute()
+            eq_(input, proc.parameters['@ovarbinary'])
+            eq_(output_type, type(proc.parameters['@ovarbinary']))
 
+        if sys.version_info[0] == 3:
+            check_conversion(bytes(b'\xDE\xAD\xBE\xEF'), bytes)
+            check_conversion(bytearray(b'\xDE\xAD\xBE\xEF'), bytes)
+            with pytest.raises(TypeError) as exc_info:
+                check_conversion('FOO', bytes)
+                assert 'value can only be bytes or bytearray' == str(exc_info.value)
+        else:
+            check_conversion(b'\xDE\xAD\xBE\xEF', str)
+            check_conversion(bytes(b'\xDE\xAD\xBE\xEF'), str)
+            check_conversion(bytearray(b'\xDE\xAD\xBE\xEF'), str)
+            with pytest.raises(TypeError) as exc_info:
+                check_conversion(unicode('Foo'), str)
+                assert 'value can only be str or bytearray' == str(exc_info.value)
+
+
+@mssql_server_required
+class TestFloatTypeConversion(unittest.TestCase):
+    def setUp(self):
+        self.mssql = mssqlconn()
+        self.pymssql = pymssqlconn()
+        cursor = self.pymssql.cursor()
+
+        self.mssql.execute_non_query("""
+            CREATE PROCEDURE [dbo].[pymssqlRealTest]
+                @inparam real
+            AS
+            BEGIN
+                SELECT @inparam AS outparam
+            END
+            """
+        )
+
+        self.mssql.execute_non_query("""
+            CREATE PROCEDURE [dbo].[pymssqlFloatTest]
+                @inparam float
+            AS
+            BEGIN
+                SELECT @inparam AS outparam
+            END
+            """
+        )
+
+    def tearDown(self):
+        cursor = self.pymssql.cursor()
+        self.mssql.execute_non_query('DROP PROCEDURE [dbo].[pymssqlRealTest]')
+        self.mssql.execute_non_query('DROP PROCEDURE [dbo].[pymssqlFloatTest]')
+        self.pymssql.close()
+
+    def testReal(self):
+        cursor = self.pymssql.cursor()
+        cursor.callproc(
+            'pymssqlRealTest',
+            (0.5,))
+
+        # TODO: Use the solution we implement once #134 gets fixed
+        a = next(cursor)
+        assert abs(a[0] - 0.5) < 0.000001
+
+    def testFloat8(self):
+        cursor = self.pymssql.cursor()
+        cursor.callproc(
+            'pymssqlFloatTest',
+            (5.44451787074e+39,))
+
+        # TODO: Use the solution we implement once #134 gets fixed
+        a = next(cursor)
+        assert abs(a[0] - 5.44451787074e+39) < 0.000001
+
+@mssql_server_required
 class TestErrorInSP(unittest.TestCase):
 
     def setUp(self):
@@ -447,6 +557,7 @@ class TestErrorInSP(unittest.TestCase):
             self.assertTrue(isinstance(e,  pymssql.DatabaseError))
 
 
+@mssql_server_required
 class TestSPWithQueryResult(unittest.TestCase):
 
     SP_NAME = 'SPWithAQuery'
