@@ -1,7 +1,13 @@
+# -*- coding: utf-8 -*-
+"""
+Test unicode usage in queries.
+"""
+
 import unittest
 
-from .helpers import pymssqlconn
+from .helpers import pymssqlconn, mssql_server_required
 
+@mssql_server_required
 class TestUnicode(unittest.TestCase):
 
     def setUp(self):
